package t1ck.widebase.db.table

import widebase.db.column. { IntColumn, StringColumn }
import widebase.db.table.Table

/** A trait to build symboled tables.
 *
 * @param table with nummerical `symbol` column
 * @param column of enumerated string symbols
 *
 * @author myst3r10n
 */
abstract class SymboledTable(table: Table, column: StringColumn = null) {

  /** Symbol. */
  object symbol {

    /** Numerical column. */
    val indexCol =
      if(column == null)
        null
      else
        table("symbol").asInstanceOf[IntColumn]

    /** String based column. */
    val stringCol =
      if(column == null)
        table("symbol").asInstanceOf[StringColumn]
      else
        column

    def apply(index: Int) =
      if(column == null)
        stringCol(index)
      else
        stringCol(indexCol(index))

    def head = apply(0)

    def last =
      if(column == null)
        stringCol.last
      else
        stringCol(indexCol.last)

  }
}

